@@ -38,6 +38,40 @@ from groundx.type.bucket_list_response import BucketListResponse
 
 from . import path
 
+# Query params
+NSchema = schemas.IntSchema
+NextTokenSchema = schemas.StrSchema
+RequestRequiredQueryParams = typing_extensions.TypedDict(
+    'RequestRequiredQueryParams',
+    {
+    }
+)
+RequestOptionalQueryParams = typing_extensions.TypedDict(
+    'RequestOptionalQueryParams',
+    {
+        'n': typing.Union[NSchema, decimal.Decimal, int, ],
+        'nextToken': typing.Union[NextTokenSchema, str, ],
+    },
+    total=False
+)
+
+
+class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
+    pass
+
+
+request_query_n = api_client.QueryParameter(
+    name="n",
+    style=api_client.ParameterStyle.FORM,
+    schema=NSchema,
+    explode=True,
+)
+request_query_next_token = api_client.QueryParameter(
+    name="nextToken",
+    style=api_client.ParameterStyle.FORM,
+    schema=NextTokenSchema,
+    explode=True,
+)
 _auth = [
     'ApiKeyAuth',
 ]
@@ -74,12 +108,21 @@ class BaseApi(api_client.Api):
 
     def _list_mapped_args(
         self,
+        n: typing.Optional[int] = None,
+        next_token: typing.Optional[str] = None,
     ) -> api_client.MappedArgs:
         args: api_client.MappedArgs = api_client.MappedArgs()
+        _query_params = {}
+        if n is not None:
+            _query_params["n"] = n
+        if next_token is not None:
+            _query_params["nextToken"] = next_token
+        args.query = _query_params
         return args
 
     async def _alist_oapg(
         self,
+            query_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
         timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
@@ -96,8 +139,23 @@ class BaseApi(api_client.Api):
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
         """
+        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
         used_path = path.value
     
+        prefix_separator_iterator = None
+        for parameter in (
+            request_query_n,
+            request_query_next_token,
+        ):
+            parameter_data = query_params.get(parameter.name, schemas.unset)
+            if parameter_data is schemas.unset:
+                continue
+            if prefix_separator_iterator is None:
+                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
+            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
+            for serialized_value in serialized_data.values():
+                used_path += serialized_value
+    
         _headers = HTTPHeaderDict()
         # TODO add cookie handling
         if accept_content_types:
@@ -117,6 +175,7 @@ class BaseApi(api_client.Api):
             method=method,
             headers=_headers,
             auth_settings=_auth,
+            prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
             **kwargs
         )
@@ -177,6 +236,7 @@ class BaseApi(api_client.Api):
 
     def _list_oapg(
         self,
+            query_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
         timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
@@ -191,8 +251,23 @@ class BaseApi(api_client.Api):
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
         """
+        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
         used_path = path.value
     
+        prefix_separator_iterator = None
+        for parameter in (
+            request_query_n,
+            request_query_next_token,
+        ):
+            parameter_data = query_params.get(parameter.name, schemas.unset)
+            if parameter_data is schemas.unset:
+                continue
+            if prefix_separator_iterator is None:
+                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
+            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
+            for serialized_value in serialized_data.values():
+                used_path += serialized_value
+    
         _headers = HTTPHeaderDict()
         # TODO add cookie handling
         if accept_content_types:
@@ -212,6 +287,7 @@ class BaseApi(api_client.Api):
             method=method,
             headers=_headers,
             auth_settings=_auth,
+            prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
         )
     
@@ -244,6 +320,8 @@ class List(BaseApi):
 
     async def alist(
         self,
+        n: typing.Optional[int] = None,
+        next_token: typing.Optional[str] = None,
         **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
@@ -251,20 +329,28 @@ class List(BaseApi):
         AsyncGeneratorResponse,
     ]:
         args = self._list_mapped_args(
+            n=n,
+            next_token=next_token,
         )
         return await self._alist_oapg(
+            query_params=args.query,
             **kwargs,
         )
     
     def list(
         self,
+        n: typing.Optional[int] = None,
+        next_token: typing.Optional[str] = None,
     ) -> typing.Union[
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
     ]:
         args = self._list_mapped_args(
+            n=n,
+            next_token=next_token,
         )
         return self._list_oapg(
+            query_params=args.query,
         )
 
 class ApiForget(BaseApi):
@@ -272,6 +358,8 @@ class ApiForget(BaseApi):
 
     async def aget(
         self,
+        n: typing.Optional[int] = None,
+        next_token: typing.Optional[str] = None,
         **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
@@ -279,19 +367,27 @@ class ApiForget(BaseApi):
         AsyncGeneratorResponse,
     ]:
         args = self._list_mapped_args(
+            n=n,
+            next_token=next_token,
         )
         return await self._alist_oapg(
+            query_params=args.query,
             **kwargs,
         )
     
     def get(
         self,
+        n: typing.Optional[int] = None,
+        next_token: typing.Optional[str] = None,
     ) -> typing.Union[
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
     ]:
         args = self._list_mapped_args(
+            n=n,
+            next_token=next_token,
         )
         return self._list_oapg(
+            query_params=args.query,
         )
 
