@@ -39,11 +39,11 @@ from groundx.type.project_response import ProjectResponse
 from . import path
 
 # Path params
-ProjectIdSchema = schemas.StrSchema
+ProjectIdSchema = schemas.IntSchema
 RequestRequiredPathParams = typing_extensions.TypedDict(
     'RequestRequiredPathParams',
     {
-        'projectId': typing.Union[ProjectIdSchema, str, ],
+        'projectId': typing.Union[ProjectIdSchema, decimal.Decimal, int, ],
     }
 )
 RequestOptionalPathParams = typing_extensions.TypedDict(
@@ -134,7 +134,7 @@ class BaseApi(api_client.Api):
 
     def _get_mapped_args(
         self,
-        project_id: str,
+        project_id: int,
     ) -> api_client.MappedArgs:
         args: api_client.MappedArgs = api_client.MappedArgs()
         _path_params = {}
@@ -339,7 +339,7 @@ class Get(BaseApi):
 
     async def aget(
         self,
-        project_id: str,
+        project_id: int,
         **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
@@ -356,7 +356,7 @@ class Get(BaseApi):
     
     def get(
         self,
-        project_id: str,
+        project_id: int,
     ) -> typing.Union[
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
@@ -373,7 +373,7 @@ class ApiForget(BaseApi):
 
     async def aget(
         self,
-        project_id: str,
+        project_id: int,
         **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
@@ -390,7 +390,7 @@ class ApiForget(BaseApi):
     
     def get(
         self,
-        project_id: str,
+        project_id: int,
     ) -> typing.Union[
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
